@@ -1,3 +1,4 @@
+from json import dumps
 import os
 import random
 import re
@@ -5,6 +6,8 @@ import sys
 
 from httpx import request
 
+from app.update.main import read_mapping
+
 sys.path.append(os.curdir)
 
 from importlib.metadata import version
@@ -13,10 +16,10 @@ import asyncio
 import typer
 import configparser
 from pathlib import Path
-from typing import Optional
+from typing import List, Optional
 from typing_extensions import Annotated
 from app.setup.utils import add_to_config, config_file
-
+from app.common import sheetType
 
 try:
     from dotenv import load_dotenv
@@ -61,11 +64,11 @@ def configGet(section: str, key: str, fallback: str = None):
 
 
 @app.command(help="Scrape data")
-def scrape(
+def scrape_from_file(
     urls_file: Path = typer.Argument(help="Path to the urls file", resolve_path=True),
-    max_workers: Annotated[int, typer.Option(help="number of workers")] = configGet(
-        "default", "max_workers"
-    ),
+    max_workers: Annotated[
+        int, typer.Option("-w", help="number of workers")
+    ] = configGet("default", "max_workers"),
     overwrite: Annotated[bool, typer.Option(help="overwrite existing data")] = False,
     skip_images: Annotated[bool, typer.Option(help="skip saving images")] = False,
 ):
@@ -163,6 +166,56 @@ def export(
     main(input_dir=input_dir, output=output_file, sort_by=sort_by)
 
 
+site_help = f"""
+Select type of sites you're scraping from
+
+[b white]ecom[/]
+example: flipkart, meesho, snapdeal
+mappings:\n
+{dumps(read_mapping(sheetType.ecom.value), indent=1)}
+
+\n
+[b white]social[/]
+example: facebook, instagram, youtube
+mappings:\n
+{dumps(read_mapping(sheetType.social.value), indent=1)}
+
+"""
+
+
+@app.command(help="Modify/Update existing sheet")
+def scrape_from_sheet(
+    input_path: Annotated[
+        str, typer.Option("--input-path", "--input", "-i", help="input file path")
+    ],
+    site: Annotated[sheetType, typer.Option(help=site_help, rich_help_panel="Site")],
+    output_dir: Annotated[
+        str,
+        typer.Option("--output-dir", "--output", "-o", help="output directory path"),
+    ] = None,
+    max_workers: Annotated[
+        int, typer.Option("-w", help="number of workers")
+    ] = configGet("default", "max_workers"),
+    overwrite: Annotated[bool, typer.Option(help="overwrite existing data")] = False,
+    skip_images: Annotated[bool, typer.Option(help="skip saving images")] = False,
+):
+    from app.update.main import main
+
+    print(f"[bold]Updating sheet from {input_path}[/]")
+    print(f"Number of workers: {max_workers}")
+    print(f"Overwrite existing data: {overwrite}")
+    print(f"Skip saving images: {skip_images}")
+
+    main(
+        input_path=input_path,
+        site=site,
+        max_workers=max_workers,
+        output_dir=output_dir,
+        overwrite=overwrite,
+        skip_images=skip_images,
+    )
+
+
 @app.command(help="List config", name="config")
 def list_configs():
     for section in config.sections():
@@ -216,7 +269,7 @@ def version_callback(show: bool):
                 )
             raise typer.Exit()
 
-        typer.echo("Invalid version format.")
+        typer.echo("Version: ", __version__)
         raise typer.Exit()
 
 
